@@ -81,11 +81,32 @@ class Transformer:
         return value
 
     def _get_image(self, host):
-        """Get image name by OS name from provisioning config."""
-        operating_system = host["os"]
-        image = self._find_value(host, "image", "images", operating_system)
+        """
+        Get image name by OS name from provisioning config.
 
-        logger.debug(f"{self.dsp_name}: Found image {image} for {operating_system}")
+        The preferred solution is to create mappings between operating system
+        and image present in the provisioning config - this only allows us
+        to change the providers without changing the input metadata.
+
+        host - dictionary with server requirements
+
+        The host dictionary can contain following attributes:
+        * 'os': operating system to find mapping to image from provisioning config
+        * 'image': image to use (optional)
+
+        Returns:
+            An image to be used, if mapping is not found it defaults to the host['os']
+            :rtype: str
+        """
+        operating_system = host["os"]
+        image = self._find_value(
+            host, "image", "images", operating_system, default=operating_system
+        )
+
+        logger.debug(
+            f"{self.dsp_name} [{host.get('name')}] Using image "
+            f"{image} for {operating_system}"
+        )
         return image
 
     def _get_flavor(self, host):
@@ -96,12 +117,14 @@ class Transformer:
         If 'size' is not specified, get the flavor based on host groups
         which are defined in provisioning config.
         """
+        log_msg_start = f"{self.dsp_name} [{host.get('name')}]"
+
         if host.get("size"):  # allow to override size by pointing to group in metadata
             flavor = get_config_value(self.config["flavors"], host["size"])
         else:  # default action based on host group define the flavor of instance
             flavor = get_config_value(self.config["flavors"], host["group"])
 
-        logger.debug(f"{self.dsp_name}: Loaded flavor for {host['name']}: '{flavor}'")
+        logger.debug(f"{log_msg_start} Loaded flavor '{flavor}'")
         return flavor
 
     def validate_config(self):
@@ -110,13 +133,15 @@ class Transformer:
 
     def validate_host(self, host):
         """Validate host input that it contains everything needed by provider."""
+        log_msg_start = f"{self.dsp_name} [{host.get('name')}]"
         # attribute check
         validate_dict_attrs(host, self._required_host_attrs, "host")
         # provider check
         provider = host.get("provider")
+
         if provider and provider not in providers.names:
             raise MetadataError(
-                f"{self.dsp_name}: Error: Invalid host provider: {provider}"
+                f"{log_msg_start} Error: Invalid host provider: {provider}"
             )
 
     def create_host_requirement(self, host):
@@ -126,5 +151,5 @@ class Transformer:
     def create_host_requirements(self):
         """Create inputs for all host for provisioner."""
         reqs = [self.create_host_requirement(host) for host in self.hosts]
-        logger.info(f"{self.dsp_name}: Created requirement(s): {object2json(reqs)}")
+        logger.info(f"{self.dsp_name} Created requirement(s): {object2json(reqs)}")
         return reqs
